@@ -16,7 +16,11 @@ class VncPreferences : public KCModule
     Q_OBJECT
 
 public:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     explicit VncPreferences(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+#else
+    explicit VncPreferences(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+#endif
     ~VncPreferences() override;
 
     void save() override;
